@@ -2,33 +2,87 @@
 
 use crate::{NetworkData, Networks, NetworksExt, UserExt};
 
-/// Trait to have a common fallback for the [`Pid`][crate::Pid] type.
-pub trait AsU32 {
+use std::convert::From;
+use std::fmt;
+use std::str::FromStr;
+
+/// Trait to have a common conversions for the [`Pid`][crate::Pid] type.
+///
+/// ```
+/// use sysinfo::{Pid, PidExt};
+///
+/// let p = Pid::from_u32(0);
+/// let value: u32 = p.as_u32();
+/// ```
+pub trait PidExt<T>: Copy + From<T> + FromStr + fmt::Display {
     /// Allows to convert [`Pid`][crate::Pid] into [`u32`].
-    fn as_u32(&self) -> u32;
+    ///
+    /// ```
+    /// use sysinfo::{Pid, PidExt};
+    ///
+    /// let p = Pid::from_u32(0);
+    /// let value: u32 = p.as_u32();
+    /// ```
+    fn as_u32(self) -> u32;
+    /// Allows to convert a [`u32`] into [`Pid`][crate::Pid].
+    ///
+    /// ```
+    /// use sysinfo::{Pid, PidExt};
+    ///
+    /// let p = Pid::from_u32(0);
+    /// ```
+    fn from_u32(v: u32) -> Self;
+}
+
+macro_rules! pid_decl {
+    ($typ:ty) => {
+        #[doc = include_str!("../md_doc/pid.md")]
+        #[derive(Clone, Copy, Debug, Hash, PartialEq, Eq, PartialOrd, Ord)]
+        pub struct Pid(pub(crate) $typ);
+
+        impl From<$typ> for Pid {
+            fn from(v: $typ) -> Self {
+                Self(v)
+            }
+        }
+        impl PidExt<$typ> for Pid {
+            fn as_u32(self) -> u32 {
+                self.0 as u32
+            }
+            fn from_u32(v: u32) -> Self {
+                Self(v as _)
+            }
+        }
+        impl FromStr for Pid {
+            type Err = <$typ as FromStr>::Err;
+            fn from_str(s: &str) -> Result<Self, Self::Err> {
+                Ok(Self(<$typ>::from_str(s)?))
+            }
+        }
+        impl fmt::Display for Pid {
+            fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+                write!(f, "{}", self.0)
+            }
+        }
+    };
 }
 
 cfg_if::cfg_if! {
-    if #[cfg(any(windows, target_os = "unknown", target_arch = "wasm32"))] {
-        /// Process id.
-        pub type Pid = usize;
-
-        impl AsU32 for Pid {
-            fn as_u32(&self) -> u32 {
-                *self as u32
-            }
-        }
-    } else {
+    if #[cfg(all(
+        not(feature = "unknown-ci"),
+        any(
+            target_os = "freebsd",
+            target_os = "linux",
+            target_os = "android",
+            target_os = "macos",
+            target_os = "ios",
+        )
+    ))] {
         use libc::pid_t;
 
-        /// Process id.
-        pub type Pid = pid_t;
-
-        impl AsU32 for Pid {
-            fn as_u32(&self) -> u32 {
-                *self as u32
-            }
-        }
+        pid_decl!(pid_t);
+    } else {
+        pid_decl!(usize);
     }
 }
 
@@ -373,6 +427,9 @@ pub enum DiskType {
 ///
 /// On non-unix systems, this enum is mostly useless and is only there to keep coherency between
 /// the different OSes.
+///
+/// If you want the list of the supported signals on the current system, use
+/// [`SystemExt::SUPPORTED_SIGNALS`][crate::SystemExt::SUPPORTED_SIGNALS].
 #[derive(Clone, Copy, PartialEq, PartialOrd, Debug)]
 pub enum Signal {
     /// Hangup detected on controlling terminal or death of controlling process.
@@ -443,6 +500,46 @@ pub enum Signal {
     Sys,
 }
 
+impl std::fmt::Display for Signal {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        let s = match *self {
+            Self::Hangup => "Hangup",
+            Self::Interrupt => "Interrupt",
+            Self::Quit => "Quit",
+            Self::Illegal => "Illegal",
+            Self::Trap => "Trap",
+            Self::Abort => "Abort",
+            Self::IOT => "IOT",
+            Self::Bus => "Bus",
+            Self::FloatingPointException => "FloatingPointException",
+            Self::Kill => "Kill",
+            Self::User1 => "User1",
+            Self::Segv => "Segv",
+            Self::User2 => "User2",
+            Self::Pipe => "Pipe",
+            Self::Alarm => "Alarm",
+            Self::Term => "Term",
+            Self::Child => "Child",
+            Self::Continue => "Continue",
+            Self::Stop => "Stop",
+            Self::TSTP => "TSTP",
+            Self::TTIN => "TTIN",
+            Self::TTOU => "TTOU",
+            Self::Urgent => "Urgent",
+            Self::XCPU => "XCPU",
+            Self::XFSZ => "XFSZ",
+            Self::VirtualAlarm => "VirtualAlarm",
+            Self::Profiling => "Profiling",
+            Self::Winch => "Winch",
+            Self::IO => "IO",
+            Self::Poll => "Poll",
+            Self::Power => "Power",
+            Self::Sys => "Sys",
+        };
+        f.write_str(s)
+    }
+}
+
 /// A struct representing system load average value.
 ///
 /// It is returned by [`SystemExt::load_average`][crate::SystemExt::load_average].
@@ -486,33 +583,40 @@ macro_rules! xid {
     };
 }
 
-#[cfg(not(target_os = "windows"))]
-xid!(
-    /// A user id wrapping a platform specific type
-    Uid,
-    libc::uid_t
-);
-
-#[cfg(target_os = "windows")]
-xid!(
-    /// A user id wrapping a platform specific type
-    Uid,
-    u32
-);
-
-#[cfg(not(target_os = "windows"))]
-xid!(
-    /// A group id wrapping a platform specific type
-    Gid,
-    libc::gid_t
-);
-
-#[cfg(target_os = "windows")]
-xid!(
-    /// A group id wrapping a platform specific type
-    Gid,
-    u32
-);
+cfg_if::cfg_if! {
+    if #[cfg(all(
+        not(feature = "unknown-ci"),
+        any(
+            target_os = "freebsd",
+            target_os = "linux",
+            target_os = "android",
+            target_os = "macos",
+            target_os = "ios",
+        )
+    ))] {
+        xid!(
+            /// A user id wrapping a platform specific type.
+            Uid,
+            libc::uid_t
+        );
+        xid!(
+            /// A group id wrapping a platform specific type.
+            Gid,
+            libc::gid_t
+        );
+    } else {
+        xid!(
+            /// A user id wrapping a platform specific type.
+            Uid,
+            u32
+        );
+        xid!(
+            /// A group id wrapping a platform specific type.
+            Gid,
+            u32
+        );
+    }
+}
 
 /// Type containing user information.
 ///
@@ -704,23 +808,25 @@ pub enum ProcessStatus {
 #[allow(clippy::unnecessary_wraps)]
 pub fn get_current_pid() -> Result<Pid, &'static str> {
     cfg_if::cfg_if! {
-        if #[cfg(target = "unknown-ci")] {
+        if #[cfg(feature = "unknown-ci")] {
             fn inner() -> Result<Pid, &'static str> {
                 Err("Unknown platform (CI)")
             }
-        } else if #[cfg(not(any(target_os = "windows", target_os = "unknown", target_arch = "wasm32")))] {
+        } else if #[cfg(any(
+            target_os = "freebsd",
+            target_os = "linux",
+            target_os = "android",
+            target_os = "macos",
+            target_os = "ios",
+        ))] {
             fn inner() -> Result<Pid, &'static str> {
-                unsafe { Ok(::libc::getpid()) }
+                unsafe { Ok(Pid(libc::getpid())) }
             }
-        } else if #[cfg(target_os = "windows")] {
+        } else if #[cfg(windows)] {
             fn inner() -> Result<Pid, &'static str> {
                 use winapi::um::processthreadsapi::GetCurrentProcessId;
 
-                unsafe { Ok(GetCurrentProcessId() as Pid) }
-            }
-        } else if #[cfg(target_os = "unknown")] {
-            fn inner() -> Result<Pid, &'static str> {
-                Err("Unavailable on this platform")
+                unsafe { Ok(Pid(GetCurrentProcessId() as _)) }
             }
         } else {
             fn inner() -> Result<Pid, &'static str> {
