@@ -7,7 +7,7 @@ use crate::sys::processor::*;
 use crate::sys::utils::get_all_data;
 use crate::{Disk, LoadAvg, Networks, Pid, ProcessRefreshKind, RefreshKind, SystemExt, User};
 
-use libc::{self, c_char, sysconf, _SC_CLK_TCK, _SC_HOST_NAME_MAX, _SC_PAGESIZE};
+use libc::{self, c_char, c_int, sysconf, _SC_CLK_TCK, _SC_HOST_NAME_MAX, _SC_PAGESIZE};
 use std::collections::HashMap;
 use std::fs::File;
 use std::io::{BufRead, BufReader, Read};
@@ -97,6 +97,58 @@ fn boot_time() -> u64 {
     }
 }
 
+pub(crate) struct SystemInfo {
+    pub(crate) page_size_kb: u64,
+    pub(crate) clock_cycle: u64,
+    pub(crate) boot_time: u64,
+}
+
+impl SystemInfo {
+    fn new() -> Self {
+        Self {
+            page_size_kb: unsafe { sysconf(_SC_PAGESIZE) / 1024 } as _,
+            clock_cycle: unsafe { sysconf(_SC_CLK_TCK) } as _,
+            boot_time: boot_time(),
+        }
+    }
+}
+
+declare_signals! {
+    c_int,
+    Signal::Hangup => libc::SIGHUP,
+    Signal::Interrupt => libc::SIGINT,
+    Signal::Quit => libc::SIGQUIT,
+    Signal::Illegal => libc::SIGILL,
+    Signal::Trap => libc::SIGTRAP,
+    Signal::Abort => libc::SIGABRT,
+    Signal::IOT => libc::SIGIOT,
+    Signal::Bus => libc::SIGBUS,
+    Signal::FloatingPointException => libc::SIGFPE,
+    Signal::Kill => libc::SIGKILL,
+    Signal::User1 => libc::SIGUSR1,
+    Signal::Segv => libc::SIGSEGV,
+    Signal::User2 => libc::SIGUSR2,
+    Signal::Pipe => libc::SIGPIPE,
+    Signal::Alarm => libc::SIGALRM,
+    Signal::Term => libc::SIGTERM,
+    Signal::Child => libc::SIGCHLD,
+    Signal::Continue => libc::SIGCONT,
+    Signal::Stop => libc::SIGSTOP,
+    Signal::TSTP => libc::SIGTSTP,
+    Signal::TTIN => libc::SIGTTIN,
+    Signal::TTOU => libc::SIGTTOU,
+    Signal::Urgent => libc::SIGURG,
+    Signal::XCPU => libc::SIGXCPU,
+    Signal::XFSZ => libc::SIGXFSZ,
+    Signal::VirtualAlarm => libc::SIGVTALRM,
+    Signal::Profiling => libc::SIGPROF,
+    Signal::Winch => libc::SIGWINCH,
+    Signal::IO => libc::SIGIO,
+    Signal::Poll => libc::SIGPOLL,
+    Signal::Power => libc::SIGPWR,
+    Signal::Sys => libc::SIGSYS,
+}
+
 #[doc = include_str!("../../md_doc/system.md")]
 pub struct System {
     process_list: Process,
@@ -110,18 +162,16 @@ pub struct System {
     swap_free: u64,
     global_processor: Processor,
     processors: Vec<Processor>,
-    page_size_kb: u64,
     components: Vec<Component>,
     disks: Vec<Disk>,
     networks: Networks,
     users: Vec<User>,
-    boot_time: u64,
     /// Field set to `false` in `update_processors` and to `true` in `refresh_processes_specifics`.
     ///
     /// The reason behind this is to avoid calling the `update_processors` more than necessary.
     /// For example when running `refresh_all` or `refresh_specifics`.
     need_processors_update: bool,
-    clock_cycle: u64,
+    info: SystemInfo,
 }
 
 impl System {
@@ -272,10 +322,13 @@ impl System {
 
 impl SystemExt for System {
     const IS_SUPPORTED: bool = true;
+    const SUPPORTED_SIGNALS: &'static [Signal] = supported_signals();
 
     fn new_with_specifics(refreshes: RefreshKind) -> System {
+        let info = SystemInfo::new();
+        let process_list = Process::new(Pid(0), None, 0, &info);
         let mut s = System {
-            process_list: Process::new(0, None, 0),
+            process_list,
             mem_total: 0,
             mem_free: 0,
             mem_available: 0,
@@ -301,14 +354,12 @@ impl SystemExt for System {
                 String::new(),
             ),
             processors: Vec::with_capacity(4),
-            page_size_kb: unsafe { sysconf(_SC_PAGESIZE) / 1024 } as _,
             components: Vec::new(),
             disks: Vec::with_capacity(2),
             networks: Networks::new(),
             users: Vec::new(),
-            boot_time: boot_time(),
             need_processors_update: true,
-            clock_cycle: unsafe { sysconf(_SC_CLK_TCK) } as _,
+            info,
         };
         s.refresh_specifics(refreshes);
         s
@@ -352,10 +403,9 @@ impl SystemExt for System {
         if refresh_procs(
             &mut self.process_list,
             Path::new("/proc"),
-            self.page_size_kb,
-            0,
+            Pid(0),
             uptime,
-            self.clock_cycle,
+            &self.info,
             refresh_kind,
         ) {
             self.clear_procs(refresh_kind);
@@ -368,10 +418,9 @@ impl SystemExt for System {
         let found = match _get_process_data(
             &Path::new("/proc/").join(pid.to_string()),
             &mut self.process_list,
-            self.page_size_kb,
-            0,
+            Pid(0),
             uptime,
-            self.clock_cycle,
+            &self.info,
             refresh_kind,
         ) {
             Ok((Some(p), pid)) => {
@@ -502,7 +551,7 @@ impl SystemExt for System {
     }
 
     fn boot_time(&self) -> u64 {
-        self.boot_time
+        self.info.boot_time
     }
 
     fn load_average(&self) -> LoadAvg {
@@ -670,8 +719,6 @@ fn get_system_info_linux(info: InfoType, path: &Path, fallback_path: &Path) -> O
 
 #[cfg(target_os = "android")]
 fn get_system_info_android(info: InfoType) -> Option<String> {
-    use libc::c_int;
-
     // https://android.googlesource.com/platform/frameworks/base/+/refs/heads/master/core/java/android/os/Build.java#58
     let name: &'static [u8] = match info {
         InfoType::Name => b"ro.product.model\0",
