@@ -124,20 +124,25 @@ pub trait DiskExt: Debug {
 
 /// Contains all the methods of the [`Process`][crate::Process] struct.
 pub trait ProcessExt: Debug {
-    /// Sends [`Signal::Kill`] to the process (which is the only signal supported on all platforms
-    /// by this crate).
+    /// Sends [`Signal::Kill`] to the process (which is the only signal supported on all supported
+    /// platforms by this crate).
     ///
     /// If you want to send another signal, take a look at [`ProcessExt::kill_with`].
     ///
+    /// To get the list of the supported signals on this system, use
+    /// [`SystemExt::SUPPORTED_SIGNALS`].
+    ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     process.kill();
     /// }
     /// ```
-    fn kill(&self) -> bool;
+    fn kill(&self) -> bool {
+        self.kill_with(Signal::Kill).unwrap_or(false)
+    }
 
     /// Sends the given `signal` to the process. If the signal doesn't exist on this platform,
     /// it'll do nothing and will return `None`. Otherwise it'll return if the signal was sent
@@ -145,11 +150,14 @@ pub trait ProcessExt: Debug {
     ///
     /// If you just want to kill the process, use [`ProcessExt::kill`] directly.
     ///
+    /// To get the list of the supported signals on this system, use
+    /// [`SystemExt::SUPPORTED_SIGNALS`].
+    ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, Signal, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, Signal, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     if process.kill_with(Signal::Kill).is_none() {
     ///         eprintln!("This signal isn't supported on this platform");
     ///     }
@@ -169,10 +177,10 @@ pub trait ProcessExt: Debug {
     /// cases it's better to use [`ProcessExt::exe`] instead (which can be empty sometimes!).
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{}", process.name());
     /// }
     /// ```
@@ -181,10 +189,10 @@ pub trait ProcessExt: Debug {
     /// Returns the command line.
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{:?}", process.cmd());
     /// }
     /// ```
@@ -193,10 +201,10 @@ pub trait ProcessExt: Debug {
     /// Returns the path to the process.
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{}", process.exe().display());
     /// }
     /// ```
@@ -205,10 +213,10 @@ pub trait ProcessExt: Debug {
     /// Returns the pid of the process.
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{}", process.pid());
     /// }
     /// ```
@@ -217,10 +225,10 @@ pub trait ProcessExt: Debug {
     /// Returns the environment variables of the process.
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{:?}", process.environ());
     /// }
     /// ```
@@ -229,10 +237,10 @@ pub trait ProcessExt: Debug {
     /// Returns the current working directory.
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{}", process.cwd().display());
     /// }
     /// ```
@@ -241,10 +249,10 @@ pub trait ProcessExt: Debug {
     /// Returns the path of the root directory.
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{}", process.root().display());
     /// }
     /// ```
@@ -253,10 +261,10 @@ pub trait ProcessExt: Debug {
     /// Returns the memory usage (in KB).
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{} KB", process.memory());
     /// }
     /// ```
@@ -265,10 +273,10 @@ pub trait ProcessExt: Debug {
     /// Returns the virtual memory usage (in KB).
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{} KB", process.virtual_memory());
     /// }
     /// ```
@@ -277,10 +285,10 @@ pub trait ProcessExt: Debug {
     /// Returns the parent pid.
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{:?}", process.parent());
     /// }
     /// ```
@@ -289,10 +297,10 @@ pub trait ProcessExt: Debug {
     /// Returns the status of the processus.
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{:?}", process.status());
     /// }
     /// ```
@@ -301,10 +309,10 @@ pub trait ProcessExt: Debug {
     /// Returns the time where the process was started (in seconds) from epoch.
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("Started at {} seconds", process.start_time());
     /// }
     /// ```
@@ -313,10 +321,10 @@ pub trait ProcessExt: Debug {
     /// Returns for how much time the process has been running (in seconds).
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("Running since {} seconds", process.run_time());
     /// }
     /// ```
@@ -332,10 +340,10 @@ pub trait ProcessExt: Debug {
     /// between two calls of this method (200 ms for example).
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{}%", process.cpu_usage());
     /// }
     /// ```
@@ -346,10 +354,10 @@ pub trait ProcessExt: Debug {
     /// ⚠️ On Windows and FreeBSD, this method actually returns **ALL** I/O read and written bytes.
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     let disk_usage = process.disk_usage();
     ///     println!("read bytes   : new/total => {}/{}",
     ///         disk_usage.read_bytes,
@@ -446,6 +454,16 @@ pub trait SystemExt: Sized + Debug + Default + Send + Sync {
     /// ```
     const IS_SUPPORTED: bool;
 
+    /// Returns the list of the supported signals on this system (used by
+    /// [`ProcessExt::kill_with`]).
+    ///
+    /// ```
+    /// use sysinfo::{System, SystemExt};
+    ///
+    /// println!("supported signals: {:?}", System::SUPPORTED_SIGNALS);
+    /// ```
+    const SUPPORTED_SIGNALS: &'static [Signal];
+
     /// Creates a new [`System`] instance with nothing loaded except the processors list. If you
     /// want to load components, network interfaces or the disks, you'll have to use the
     /// `refresh_*_list` methods. [`SystemExt::refresh_networks_list`] for example.
@@ -615,6 +633,9 @@ pub trait SystemExt: Sized + Debug + Default + Send + Sync {
     ///
     /// It does the same as `system.refresh_processes_specifics(ProcessRefreshKind::everything())`.
     ///
+    /// ⚠️ On Linux, `sysinfo` keeps the `stat` files open by default. You can this behaviour by
+    /// using [`set_open_files_limit`][crate::set_open_files_limit].
+    ///
     /// ```no_run
     /// use sysinfo::{System, SystemExt};
     ///
@@ -627,6 +648,9 @@ pub trait SystemExt: Sized + Debug + Default + Send + Sync {
 
     /// Gets all processes and updates the specified information.
     ///
+    /// ⚠️ On Linux, `sysinfo` keeps the `stat` files open by default. You can this behaviour by
+    /// using [`set_open_files_limit`][crate::set_open_files_limit].
+    ///
     /// ```no_run
     /// use sysinfo::{ProcessRefreshKind, System, SystemExt};
     ///
@@ -642,10 +666,10 @@ pub trait SystemExt: Sized + Debug + Default + Send + Sync {
     /// `sys.refresh_process_specifics(pid, ProcessRefreshKind::everything())`.
     ///
     /// ```no_run
-    /// use sysinfo::{System, SystemExt};
+    /// use sysinfo::{Pid, System, SystemExt};
     ///
     /// let mut s = System::new_all();
-    /// s.refresh_process(1337);
+    /// s.refresh_process(Pid::from(1337));
     /// ```
     fn refresh_process(&mut self, pid: Pid) -> bool {
         self.refresh_process_specifics(pid, ProcessRefreshKind::everything())
@@ -655,10 +679,10 @@ pub trait SystemExt: Sized + Debug + Default + Send + Sync {
     /// exist. If it isn't listed yet, it'll be added.
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessRefreshKind, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessRefreshKind, System, SystemExt};
     ///
     /// let mut s = System::new_all();
-    /// s.refresh_process_specifics(1337, ProcessRefreshKind::new());
+    /// s.refresh_process_specifics(Pid::from(1337), ProcessRefreshKind::new());
     /// ```
     fn refresh_process_specifics(&mut self, pid: Pid, refresh_kind: ProcessRefreshKind) -> bool;
 
@@ -774,33 +798,63 @@ pub trait SystemExt: Sized + Debug + Default + Send + Sync {
     /// Returns the process corresponding to the given pid or `None` if no such process exists.
     ///
     /// ```no_run
-    /// use sysinfo::{ProcessExt, System, SystemExt};
+    /// use sysinfo::{Pid, ProcessExt, System, SystemExt};
     ///
     /// let s = System::new_all();
-    /// if let Some(process) = s.process(1337) {
+    /// if let Some(process) = s.process(Pid::from(1337)) {
     ///     println!("{}", process.name());
     /// }
     /// ```
     fn process(&self, pid: Pid) -> Option<&Process>;
 
-    /// Returns a list of process containing the given `name`.
+    /// Returns an iterator of process containing the given `name`.
+    ///
+    /// If you want only the processes with exactly the given `name`, take a look at
+    /// [`SystemExt::processes_by_exact_name`].
     ///
     /// ```no_run
     /// use sysinfo::{ProcessExt, System, SystemExt};
     ///
     /// let s = System::new_all();
-    /// for process in s.process_by_name("htop") {
+    /// for process in s.processes_by_name("htop") {
     ///     println!("{} {}", process.pid(), process.name());
     /// }
     /// ```
-    fn process_by_name(&self, name: &str) -> Vec<&Process> {
-        let mut ret = vec![];
-        for val in self.processes().values() {
-            if val.name().contains(name) {
-                ret.push(val);
-            }
-        }
-        ret
+    // FIXME: replace the returned type with `impl Iterator<Item = &Process>` when it's supported!
+    fn processes_by_name<'a>(
+        &'a self,
+        name: &'a str,
+    ) -> Box<dyn Iterator<Item = &'a Process> + 'a> {
+        Box::new(
+            self.processes()
+                .values()
+                .filter(move |val: &&Process| val.name().contains(name)),
+        )
+    }
+
+    /// Returns an iterator of processes with exactly the given `name`.
+    ///
+    /// If you instead want the processes containing `name`, take a look at
+    /// [`SystemExt::processes_by_name`].
+    ///
+    /// ```no_run
+    /// use sysinfo::{ProcessExt, System, SystemExt};
+    ///
+    /// let s = System::new_all();
+    /// for process in s.processes_by_exact_name("htop") {
+    ///     println!("{} {}", process.pid(), process.name());
+    /// }
+    /// ```
+    // FIXME: replace the returned type with `impl Iterator<Item = &Process>` when it's supported!
+    fn processes_by_exact_name<'a>(
+        &'a self,
+        name: &'a str,
+    ) -> Box<dyn Iterator<Item = &'a Process> + 'a> {
+        Box::new(
+            self.processes()
+                .values()
+                .filter(move |val: &&Process| val.name() == name),
+        )
     }
 
     /// Returns "global" processors information (aka the addition of all the processors).
