@@ -53,11 +53,11 @@ impl fmt::Display for ProcessStatus {
 }
 
 fn get_process_handler(pid: Pid) -> Option<HANDLE> {
-    if pid == 0 {
+    if pid.0 == 0 {
         return None;
     }
     let options = PROCESS_QUERY_INFORMATION | PROCESS_VM_READ;
-    let process_handler = unsafe { OpenProcess(options, FALSE, pid as DWORD) };
+    let process_handler = unsafe { OpenProcess(options, FALSE, pid.0 as DWORD) };
     if process_handler.is_null() {
         None
     } else {
@@ -175,7 +175,7 @@ unsafe fn get_exe(process_handler: HANDLE, h_mod: *mut c_void) -> PathBuf {
 impl Process {
     #[allow(clippy::uninit_assumed_init)]
     pub(crate) fn new_from_pid(pid: Pid, now: u64) -> Option<Process> {
-        let process_handler = unsafe { OpenProcess(PROCESS_QUERY_INFORMATION, FALSE, pid as _) };
+        let process_handler = unsafe { OpenProcess(PROCESS_QUERY_INFORMATION, FALSE, pid.0 as _) };
         if process_handler.is_null() {
             return None;
         }
@@ -196,7 +196,7 @@ impl Process {
         Some(Process::new_with_handle(
             pid,
             if info.InheritedFromUniqueProcessId as usize != 0 {
-                Some(info.InheritedFromUniqueProcessId as usize)
+                Some(Pid(info.InheritedFromUniqueProcessId as _))
             } else {
                 None
             },
@@ -792,6 +792,7 @@ fn check_sub(a: u64, b: u64) -> u64 {
         a - b
     }
 }
+
 /// Before changing this function, you must consider the following:
 /// https://github.com/GuillaumeGomez/sysinfo/issues/459
 pub(crate) fn compute_cpu_usage(p: &mut Process, nb_processors: u64) {
@@ -871,11 +872,11 @@ pub(crate) fn compute_cpu_usage(p: &mut Process, nb_processors: u64) {
     }
 }
 
-pub fn get_handle(p: &Process) -> HANDLE {
+pub(crate) fn get_handle(p: &Process) -> HANDLE {
     *p.handle
 }
 
-pub fn update_disk_usage(p: &mut Process) {
+pub(crate) fn update_disk_usage(p: &mut Process) {
     let mut counters = MaybeUninit::<IO_COUNTERS>::uninit();
     let ret = unsafe { GetProcessIoCounters(*p.handle, counters.as_mut_ptr()) };
     if ret == 0 {
@@ -889,7 +890,7 @@ pub fn update_disk_usage(p: &mut Process) {
     }
 }
 
-pub fn update_memory(p: &mut Process) {
+pub(crate) fn update_memory(p: &mut Process) {
     unsafe {
         let mut pmc: PROCESS_MEMORY_COUNTERS_EX = zeroed();
         if GetProcessMemoryInfo(
